package com.ruoyi.invest.service;

import com.ruoyi.invest.domain.TProjectChannel;

import java.util.List;

/**
 * 渠道信息Service接口
 * 
 * @author ruoyi
 * @date 2024-02-22
 */
public interface ITProjectChannelService 
{
    /**
     * 查询渠道信息
     * 
     * @param id 渠道信息主键
     * @return 渠道信息
     */
    public TProjectChannel selectTProjectChannelById(String id);

    /**
     * 查询渠道信息列表
     * 
     * @param tProjectChannel 渠道信息
     * @return 渠道信息集合
     */
    public List<TProjectChannel> selectTProjectChannelList(TProjectChannel tProjectChannel);

    /**
     * 新增渠道信息
     * 
     * @param tProjectChannel 渠道信息
     * @return 结果
     */
    public int insertTProjectChannel(TProjectChannel tProjectChannel);

    /**
     * 修改渠道信息
     * 
     * @param tProjectChannel 渠道信息
     * @return 结果
     */
    public int updateTProjectChannel(TProjectChannel tProjectChannel);

    /**
     * 批量删除渠道信息
     * 
     * @param ids 需要删除的渠道信息主键集合
     * @return 结果
     */
    public int deleteTProjectChannelByIds(String[] ids);

    /**
     * 删除渠道信息信息
     * 
     * @param id 渠道信息主键
     * @return 结果
     */
    public int deleteTProjectChannelById(String id);

    /**
     * 批量删除渠道信息(修改del_flag状态)
     * @param ids
     * @return
     */
    public int updateTProjectChannelByIds(String[] ids);

    /**
     * 根据年查询渠道编号
     * @param year
     * @return
     */
    int selectTProjectChannelCode(String year);
}
